==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Autonumer.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypAutonumeracji;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Autonumer extends GenericDPSObject {
    /**
     * AUTONUMER.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypAutonumeracji typ;

    /**
     * AUTONUMER.FORMAT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String format;

    /**
     * AUTONUMER.WARTOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer wartosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return AUTONUMER.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypAutonumeracji getTyp() {
        return typ;
    }

    /**
     * AUTONUMER.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypAutonumeracji typ) {
        this.typ = typ;
    }

    /**
     * @return AUTONUMER.FORMAT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getFormat() {
        return format;
    }

    /**
     * AUTONUMER.FORMAT
     *
     * @param format
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFormat(String format) {
        this.format = format == null ? null : format.trim();
    }

    /**
     * @return AUTONUMER.WARTOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getWartosc() {
        return wartosc;
    }

    /**
     * AUTONUMER.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartosc(Integer wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Autonumer other = (Autonumer) that;
        return (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getFormat() == null ? other.getFormat() == null : this.getFormat().equals(other.getFormat()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getFormat() == null) ? 0 : getFormat().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", typ=").append(typ);
        sb.append(", format=").append(format);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Autonumer.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypAutonumeracji;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Autonumer extends GenericDPSObject {
    /**
     * AUTONUMER.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypAutonumeracji typ;

    /**
     * AUTONUMER.FORMAT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String format;

    /**
     * AUTONUMER.WARTOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer wartosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return AUTONUMER.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypAutonumeracji getTyp() {
        return typ;
    }

    /**
     * AUTONUMER.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypAutonumeracji typ) {
        this.typ = typ;
    }

    /**
     * @return AUTONUMER.FORMAT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getFormat() {
        return format;
    }

    /**
     * AUTONUMER.FORMAT
     *
     * @param format
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFormat(String format) {
        this.format = format == null ? null : format.trim();
    }

    /**
     * @return AUTONUMER.WARTOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getWartosc() {
        return wartosc;
    }

    /**
     * AUTONUMER.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartosc(Integer wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Autonumer other = (Autonumer) that;
        return (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getFormat() == null ? other.getFormat() == null : this.getFormat().equals(other.getFormat()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getFormat() == null) ? 0 : getFormat().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", typ=").append(typ);
        sb.append(", format=").append(format);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}
